Struct amazon_sp_merchant_fulfillment::models::terms_and_conditions_not_accepted_carrier::TermsAndConditionsNotAcceptedCarrier
source · [−]pub struct TermsAndConditionsNotAcceptedCarrier {
pub carrier_name: String,
}Expand description
TermsAndConditionsNotAcceptedCarrier : A carrier whose terms and conditions have not been accepted by the seller.
Fields
carrier_name: StringThe name of the carrier.
Implementations
sourceimpl TermsAndConditionsNotAcceptedCarrier
impl TermsAndConditionsNotAcceptedCarrier
sourcepub fn new(carrier_name: String) -> TermsAndConditionsNotAcceptedCarrier
pub fn new(carrier_name: String) -> TermsAndConditionsNotAcceptedCarrier
A carrier whose terms and conditions have not been accepted by the seller.